@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate test stubs for methods
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0300';
 
 use Moo;
 use strictures 2;
@@ -56,7 +56,7 @@ sub unit_test {
             . 'isa_ok $obj, "' . $self->class . '";';
     }
     else {
-        $test = 'ok $obj->' . $subroutine . ', "' . $subroutine . '";';
+        $test = 'ok $obj->can("' . $subroutine . '"), "' . $subroutine . '";';
     }
 
     return $test;
@@ -110,7 +110,7 @@ Test::NaiveStubs - Generate test stubs for methods
 
 =head1 VERSION
 
-version 0.0202
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -174,6 +174,10 @@ Return the text of a method unit test.
 
 Create a test file with unit tests for each method.
 
+A C<new> method is extracted and processed first with C<use_ok>, object
+instantiation, followed by C<isa_ok>.  Then each seen method is returned as
+an ok can("method") assertion.
+
 =head1 SEE ALSO
 
 L<Moo>
